# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from chat_server_connector_v2.models.ai_assistant_get import AiAssistantGet
from chat_server_connector_v2.models.chat_member_role import ChatMemberRole
from chat_server_connector_v2.models.contact import Contact
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ChatMemberGet(BaseModel):
    """
    ChatMemberGet
    """ # noqa: E501
    role: Optional[ChatMemberRole] = None
    user_id: Optional[StrictInt] = None
    bot_id: Optional[StrictInt] = None
    id: StrictInt
    chat_id: StrictInt
    added_at: StrictInt
    last_seen_at: Optional[StrictInt] = None
    is_removed: Optional[StrictBool] = False
    is_banned: Optional[StrictBool] = False
    is_muted: Optional[StrictBool] = False
    user: Optional[Contact] = None
    bot: Optional[AiAssistantGet] = None
    __properties: ClassVar[List[str]] = ["role", "user_id", "bot_id", "id", "chat_id", "added_at", "last_seen_at", "is_removed", "is_banned", "is_muted", "user", "bot"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChatMemberGet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bot
        if self.bot:
            _dict['bot'] = self.bot.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChatMemberGet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "role": obj.get("role"),
            "user_id": obj.get("user_id"),
            "bot_id": obj.get("bot_id"),
            "id": obj.get("id"),
            "chat_id": obj.get("chat_id"),
            "added_at": obj.get("added_at"),
            "last_seen_at": obj.get("last_seen_at"),
            "is_removed": obj.get("is_removed") if obj.get("is_removed") is not None else False,
            "is_banned": obj.get("is_banned") if obj.get("is_banned") is not None else False,
            "is_muted": obj.get("is_muted") if obj.get("is_muted") is not None else False,
            "user": Contact.from_dict(obj["user"]) if obj.get("user") is not None else None,
            "bot": AiAssistantGet.from_dict(obj["bot"]) if obj.get("bot") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.models.chat_message_insert import ChatMessageInsert

class TestChatMessageInsert(unittest.TestCase):
    """ChatMessageInsert unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatMessageInsert:
        """Test ChatMessageInsert
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatMessageInsert`
        """
        model = ChatMessageInsert()
        if include_optional:
            return ChatMessageInsert(
                text = '',
                file_id = '',
                chat_message_type = 'TEXT',
                attachments = [
                    chat_server_connector_v2.models.chat_message_attachment_create.ChatMessageAttachmentCreate(
                        file_id = '', 
                        attachment_type = 'IMAGE', )
                    ],
                chat_member_id = 56,
                chat_session_id = 56,
                is_hidden = True,
                run_id = ''
            )
        else:
            return ChatMessageInsert(
                chat_member_id = 56,
        )
        """

    def testChatMessageInsert(self):
        """Test ChatMessageInsert"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from chat_server_connector_v2.models.ai_assistant_get import AiAssistantGet
from chat_server_connector_v2.models.ai_assistant_goal_get import AiAssistantGoalGet
from chat_server_connector_v2.models.ai_assistant_lexicon_item import AiAssistantLexiconItem
from chat_server_connector_v2.models.assistant_function import AssistantFunction
from chat_server_connector_v2.models.assistant_usage_type import AssistantUsageType
from chat_server_connector_v2.models.chat_get_with_members import ChatGetWithMembers
from chat_server_connector_v2.models.chat_get_with_members_and_messages import ChatGetWithMembersAndMessages
from chat_server_connector_v2.models.chat_get_with_members_and_messages_with_metadata import ChatGetWithMembersAndMessagesWithMetadata
from chat_server_connector_v2.models.chat_list_get import ChatListGet
from chat_server_connector_v2.models.chat_member_create_or_update import ChatMemberCreateOrUpdate
from chat_server_connector_v2.models.chat_member_get import ChatMemberGet
from chat_server_connector_v2.models.chat_member_role import ChatMemberRole
from chat_server_connector_v2.models.chat_member_role_add import ChatMemberRoleAdd
from chat_server_connector_v2.models.chat_message import ChatMessage
from chat_server_connector_v2.models.chat_message_attachment_create import ChatMessageAttachmentCreate
from chat_server_connector_v2.models.chat_message_attachment_read import ChatMessageAttachmentRead
from chat_server_connector_v2.models.chat_message_attachment_read_with_metadata import ChatMessageAttachmentReadWithMetadata
from chat_server_connector_v2.models.chat_message_attachment_type import ChatMessageAttachmentType
from chat_server_connector_v2.models.chat_message_create import ChatMessageCreate
from chat_server_connector_v2.models.chat_message_insert import ChatMessageInsert
from chat_server_connector_v2.models.chat_message_read import ChatMessageRead
from chat_server_connector_v2.models.chat_message_read_with_metadata import ChatMessageReadWithMetadata
from chat_server_connector_v2.models.chat_message_type import ChatMessageType
from chat_server_connector_v2.models.chat_new import ChatNew
from chat_server_connector_v2.models.chat_patch import ChatPatch
from chat_server_connector_v2.models.chat_session_get import ChatSessionGet
from chat_server_connector_v2.models.chat_session_get_with_chat_data import ChatSessionGetWithChatData
from chat_server_connector_v2.models.chat_session_type import ChatSessionType
from chat_server_connector_v2.models.chat_settings_create_or_update import ChatSettingsCreateOrUpdate
from chat_server_connector_v2.models.chat_settings_get import ChatSettingsGet
from chat_server_connector_v2.models.chat_type import ChatType
from chat_server_connector_v2.models.chat_update import ChatUpdate
from chat_server_connector_v2.models.collection_state import CollectionState
from chat_server_connector_v2.models.collection_status import CollectionStatus
from chat_server_connector_v2.models.consumed_units import ConsumedUnits
from chat_server_connector_v2.models.contact import Contact
from chat_server_connector_v2.models.contact_address import ContactAddress
from chat_server_connector_v2.models.conversation_style import ConversationStyle
from chat_server_connector_v2.models.course_module_public import CourseModulePublic
from chat_server_connector_v2.models.course_payment_type_str_enum import CoursePaymentTypeStrEnum
from chat_server_connector_v2.models.course_public import CoursePublic
from chat_server_connector_v2.models.external_system_message import ExternalSystemMessage
from chat_server_connector_v2.models.external_system_type import ExternalSystemType
from chat_server_connector_v2.models.external_system_user_get import ExternalSystemUserGet
from chat_server_connector_v2.models.external_system_user_update import ExternalSystemUserUpdate
from chat_server_connector_v2.models.goal_engagement_preset_get import GoalEngagementPresetGet
from chat_server_connector_v2.models.goal_interactions_summary import GoalInteractionsSummary
from chat_server_connector_v2.models.http_validation_error import HTTPValidationError
from chat_server_connector_v2.models.knowledgebase_state import KnowledgebaseState
from chat_server_connector_v2.models.location_inner import LocationInner
from chat_server_connector_v2.models.module_lesson_public import ModuleLessonPublic
from chat_server_connector_v2.models.response_wrapper import ResponseWrapper
from chat_server_connector_v2.models.response_wrapper_bool import ResponseWrapperBool
from chat_server_connector_v2.models.response_wrapper_chat_get_with_members_and_messages import ResponseWrapperChatGetWithMembersAndMessages
from chat_server_connector_v2.models.response_wrapper_chat_get_with_members_and_messages_with_metadata import ResponseWrapperChatGetWithMembersAndMessagesWithMetadata
from chat_server_connector_v2.models.response_wrapper_chat_message_read_with_metadata import ResponseWrapperChatMessageReadWithMetadata
from chat_server_connector_v2.models.response_wrapper_chat_session_get import ResponseWrapperChatSessionGet
from chat_server_connector_v2.models.response_wrapper_chat_session_get_with_chat_data import ResponseWrapperChatSessionGetWithChatData
from chat_server_connector_v2.models.response_wrapper_chat_settings_get import ResponseWrapperChatSettingsGet
from chat_server_connector_v2.models.response_wrapper_contact import ResponseWrapperContact
from chat_server_connector_v2.models.response_wrapper_external_system_user_get import ResponseWrapperExternalSystemUserGet
from chat_server_connector_v2.models.response_wrapper_int import ResponseWrapperInt
from chat_server_connector_v2.models.response_wrapper_list_chat_list_get import ResponseWrapperListChatListGet
from chat_server_connector_v2.models.response_wrapper_list_chat_member_get import ResponseWrapperListChatMemberGet
from chat_server_connector_v2.models.response_wrapper_list_chat_message_read_with_metadata import ResponseWrapperListChatMessageReadWithMetadata
from chat_server_connector_v2.models.response_wrapper_list_chat_session_get_with_chat_data import ResponseWrapperListChatSessionGetWithChatData
from chat_server_connector_v2.models.response_wrapper_list_contact import ResponseWrapperListContact
from chat_server_connector_v2.models.result import Result
from chat_server_connector_v2.models.role_enum import RoleEnum
from chat_server_connector_v2.models.usage_data_from_front import UsageDataFromFront
from chat_server_connector_v2.models.usage_data_from_front_v2 import UsageDataFromFrontV2
from chat_server_connector_v2.models.usage_data_v2 import UsageDataV2
from chat_server_connector_v2.models.validation_error import ValidationError

